@@ -232,8 +232,7 @@ const EvinceView = new Lang.Class({
     },
 
     onLoadStarted: function(manager, doc) {
-        if (doc.viewType != Documents.ViewType.EV)
-            return;
+        this.parent(manager, doc);
 
         this.getAction('bookmark-page').enabled = false;
         this.getAction('places').enabled = false;
@@ -242,9 +241,6 @@ const EvinceView = new Lang.Class({
     onLoadFinished: function(manager, doc, docModel) {
         this.parent(manager, doc, docModel);
 
-        if (doc.viewType != Documents.ViewType.EV)
-            return;
-
         this.controlsVisible = false;
         this._lastSearch = '';
         this._model = docModel;
